@@ -10,7 +10,7 @@ from kubernetes.client.api_client import ApiClient
 from mcli import config
 from mcli.cli.m_get.display import MCLIDisplayItem, MCLIGetDisplay, OutputDisplay
 from mcli.models import MCLIPlatform
-from mcli.serverside.platforms.registry import PlatformRegistry
+from mcli.serverside.platforms import GenericK8sPlatform
 from mcli.utils.utils_kube_labels import label
 from mcli.utils.utils_pypi import NeedsUpdateError, check_new_update_available
 
@@ -187,7 +187,7 @@ def get_jobs_from_namespace(
         if priority_class_name:
             # TODO: Abstract and remove
 
-            k8s_platform = PlatformRegistry().get_k8s_platform(platform=platform)
+            k8s_platform = GenericK8sPlatform.from_mcli_platform(platform)
             reverse_priority = {v: k for k, v in k8s_platform.priority_class_labels.items()}
             priority_class = reverse_priority.get(priority_class_name, 'unknown')
 
